@@ -1,10 +1,10 @@
 import asyncio
 import json
-from functools import wraps
 import os
+from functools import wraps
 
-from .flow import CloudFlow, _terminate_flow_simplified
 from .constants import Status
+from .flow import CloudFlow, _terminate_flow_simplified
 
 
 def asyncify(f):
@@ -50,7 +50,7 @@ async def status(args):
                     v = Syntax(
                         v, 'yaml', theme='monokai', line_numbers=True, code_width=40
                     )
-                elif k == 'envs' and v:
+                elif k in ('envs', 'endpoints') and v:
                     v = JSON(json.dumps(v))
                 else:
                     v = str(v)
@@ -76,7 +76,7 @@ async def _list_by_status(status):
             return dt
 
     _t = Table(
-        'ID', 'Status', 'Gateway', 'Created (UTC)', box=box.ROUNDED, highlight=True
+        'ID', 'Status', 'Endpoint(s)', 'Created (UTC)', box=box.ROUNDED, highlight=True
     )
 
     console = Console(highlighter=CustomHighlighter())
@@ -88,10 +88,14 @@ async def _list_by_status(status):
         _result = await CloudFlow().list_all(status=status)
         if _result:
             for k in _result:
+                if k['gateway'] is None and k.get('endpoints') is not None:
+                    _endpoint = json.dumps(k['endpoints'], indent=2, sort_keys=True)
+                else:
+                    _endpoint = k['gateway']
                 _t.add_row(
                     k['id'].split('-')[-1],
                     k['status'],
-                    k['gateway'],
+                    _endpoint,
                     cleanup(k['ctime']),
                 )
             console.print(_t)
@@ -135,7 +139,8 @@ async def remove(args):
     else:
         if 'JCLOUD_NO_INTERACTIVE' not in os.environ:
             confirm_deleting_all = Confirm.ask(
-                f'[red]Are you sure you want to delete ALL the ALIVE flows that belong to you?[/red]'
+                f'[red]Are you sure you want to delete ALL the ALIVE flows that belong to you?[/red]',
+                default=True,
             )
             if not confirm_deleting_all:
                 print('[cyan]No worries. Exiting...[/cyan]')
@@ -146,7 +151,7 @@ async def remove(args):
 
         if 'JCLOUD_NO_INTERACTIVE' not in os.environ:
             confirm_deleting_again = Confirm.ask(
-                '[red]Are you sure you want to delete them?[/red]'
+                '[red]Are you sure you want to delete them?[/red]', default=True
             )
             if not confirm_deleting_again:
                 print('[cyan]No worries. Exiting...[/cyan]')
@@ -158,6 +163,8 @@ async def remove(args):
 
 
 async def _remove_multi(flow_id_list):
+    from rich import print
+
     from .helper import get_pbar
 
     num_flows_to_remove = len(flow_id_list)
@@ -214,11 +221,10 @@ async def logs(args):
         await CloudFlow.logstream(_params)
 
 
-@asyncify
-async def login(args):
-    from .auth import Auth
+def login(args):
+    from auth.api import login
 
-    await Auth.login()
+    login(args)
 
 
 def new(args):
@@ -239,6 +245,6 @@ def new(args):
 
 def survey(args):
     # ask feedback
-    from .auth import Survey
+    from .survey import Survey
 
     Survey().ask(-1)
